svn commit: r259247 - head/sys/geom

2013-12-12 Thread Alexander Motin
Author: mav
Date: Thu Dec 12 08:23:28 2013
New Revision: 259247
URL: http://svnweb.freebsd.org/changeset/base/259247

Log:
  Fix bug introduced at r256607.  We have to recalculate bp_resid here since
  sizes of original and completed requests may differ due to end of media.
  
  Bisected by:  pho

Modified:
  head/sys/geom/geom_dev.c

Modified: head/sys/geom/geom_dev.c
==
--- head/sys/geom/geom_dev.cThu Dec 12 05:49:27 2013(r259246)
+++ head/sys/geom/geom_dev.cThu Dec 12 08:23:28 2013(r259247)
@@ -487,7 +487,7 @@ g_dev_done(struct bio *bp2)
bp = bp2-bio_parent;
bp-bio_error = bp2-bio_error;
bp-bio_completed = bp2-bio_completed;
-   bp-bio_resid = bp2-bio_resid;
+   bp-bio_resid = bp-bio_length - bp2-bio_completed;
if (bp2-bio_error != 0) {
g_trace(G_T_BIO, g_dev_done(%p) had error %d,
bp2, bp2-bio_error);
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259248 - head/sys/dev/usb/controller

2013-12-12 Thread Hans Petter Selasky
Author: hselasky
Date: Thu Dec 12 08:34:51 2013
New Revision: 259248
URL: http://svnweb.freebsd.org/changeset/base/259248

Log:
  Set chain bit correctly. This will fix some problems sending and
  receiving Zero Length Packets, ZLPs. See comment in code for more
  information.
  
  MFC after:1 week
  Reported by:  Kohji Okuno okuno.ko...@jp.panasonic.com

Modified:
  head/sys/dev/usb/controller/xhci.c

Modified: head/sys/dev/usb/controller/xhci.c
==
--- head/sys/dev/usb/controller/xhci.c  Thu Dec 12 08:23:28 2013
(r259247)
+++ head/sys/dev/usb/controller/xhci.c  Thu Dec 12 08:34:51 2013
(r259248)
@@ -1892,7 +1892,16 @@ restart:
td-td_trb[x].dwTrb2 = htole32(dword);
 
dword = XHCI_TRB_3_TYPE_SET(XHCI_TRB_TYPE_LINK) |
-   XHCI_TRB_3_CYCLE_BIT | XHCI_TRB_3_IOC_BIT;
+   XHCI_TRB_3_CYCLE_BIT | XHCI_TRB_3_IOC_BIT |
+   /*
+* CHAIN-BIT: Ensure that a multi-TRB IN-endpoint
+* frame only receives a single short packet event
+* by setting the CHAIN bit in the LINK field. In
+* addition some XHCI controllers have problems
+* sending a ZLP unless the CHAIN-BIT is set in
+* the LINK TRB.
+*/
+   XHCI_TRB_3_CHAIN_BIT;
 
td-td_trb[x].dwTrb3 = htole32(dword);
 
@@ -1930,7 +1939,7 @@ restart:
}
 
/* clear TD SIZE to zero, hence this is the last TRB */
-   /* remove chain bit because this is the last TRB in the chain */
+   /* remove chain bit because this is the last data TRB in the chain */
td-td_trb[td-ntrb - 1].dwTrb2 = ~htole32(XHCI_TRB_2_TDSZ_SET(15));
td-td_trb[td-ntrb - 1].dwTrb3 = ~htole32(XHCI_TRB_3_CHAIN_BIT);
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259249 - head/usr.bin/dtc

2013-12-12 Thread David Chisnall
Author: theraven
Date: Thu Dec 12 08:48:45 2013
New Revision: 259249
URL: http://svnweb.freebsd.org/changeset/base/259249

Log:
  Fix the version string in dts emission.
  
  Reported by:  Patrick Wildt
  MFC after:1 week

Modified:
  head/usr.bin/dtc/fdt.cc

Modified: head/usr.bin/dtc/fdt.cc
==
--- head/usr.bin/dtc/fdt.cc Thu Dec 12 08:34:51 2013(r259248)
+++ head/usr.bin/dtc/fdt.cc Thu Dec 12 08:48:45 2013(r259249)
@@ -1181,7 +1181,7 @@ void
 device_tree::write_dts(int fd)
 {
FILE *file = fdopen(fd, w);
-   fputs(/dtc-v1/;\n\n, file);
+   fputs(/dts-v1/;\n\n, file);
 
if (!reservations.empty())
{
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259250 - head/usr.bin/dtc

2013-12-12 Thread David Chisnall
Author: theraven
Date: Thu Dec 12 08:55:24 2013
New Revision: 259250
URL: http://svnweb.freebsd.org/changeset/base/259250

Log:
  Some more cleanups and bug fixes in dtc for property printing / parsing.
  
  Submitted by: Patrick Wildt

Modified:
  head/usr.bin/dtc/fdt.cc

Modified: head/usr.bin/dtc/fdt.cc
==
--- head/usr.bin/dtc/fdt.cc Thu Dec 12 08:48:45 2013(r259249)
+++ head/usr.bin/dtc/fdt.cc Thu Dec 12 08:55:24 2013(r259250)
@@ -137,7 +137,7 @@ property_value::resolve_type()
break;
}
}
-   if (is_all_printable  (bytes  nuls))
+   if ((is_all_printable  (bytes  nuls)) || bytes == 0)
{
type = STRING;
if (nuls  0)
@@ -204,7 +204,7 @@ property_value::write_as_bytes(FILE *fil
putc('[', file);
for (byte_buffer::iterator i=byte_data.begin(), e=byte_data.end(); i!=e 
; i++)
{
-   fprintf(file, %hhx, *i);
+   fprintf(file, %02hhx, *i);
if (i+1 != e)
{
putc(' ', file);
@@ -367,6 +367,11 @@ property::property(input_buffer structs
return;
}
key = string(name_buffer);
+
+   // If we're empty, do not push anything as value.
+   if (!length)
+   return;
+
// Read the value
uint8_t byte;
property_value v;
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259254 - head/sys/fs/devfs

2013-12-12 Thread Alexander Motin
Author: mav
Date: Thu Dec 12 11:05:48 2013
New Revision: 259254
URL: http://svnweb.freebsd.org/changeset/base/259254

Log:
  Fix long known bug with handling device aliases residing not in devfs root.
  
  Historically creation of device aliases created symbolic links using only
  name of target device as a link target, not considering current directory.
  Fix that by adding number of ../ chunks to the terget device name,
  required to get out of the current directory to devfs root first.
  
  MFC after:1 month

Modified:
  head/sys/fs/devfs/devfs_devs.c

Modified: head/sys/fs/devfs/devfs_devs.c
==
--- head/sys/fs/devfs/devfs_devs.c  Thu Dec 12 10:57:16 2013
(r259253)
+++ head/sys/fs/devfs/devfs_devs.c  Thu Dec 12 11:05:48 2013
(r259254)
@@ -486,9 +486,9 @@ devfs_populate_loop(struct devfs_mount *
 {
struct cdev_priv *cdp;
struct devfs_dirent *de;
-   struct devfs_dirent *dd;
+   struct devfs_dirent *dd, *dt;
struct cdev *pdev;
-   int de_flags, j;
+   int de_flags, depth, j;
char *q, *s;
 
sx_assert(dm-dm_lock, SX_XLOCKED);
@@ -589,9 +589,17 @@ devfs_populate_loop(struct devfs_mount *
de-de_mode = 0755;
de-de_dirent-d_type = DT_LNK;
pdev = cdp-cdp_c.si_parent;
-   j = strlen(pdev-si_name) + 1;
+   dt = dd;
+   depth = 0;
+   while (dt != dm-dm_rootdir 
+   (dt = devfs_parent_dirent(dt)) != NULL)
+   depth++;
+   j = depth * 3 + strlen(pdev-si_name) + 1;
de-de_symlink = malloc(j, M_DEVFS, M_WAITOK);
-   bcopy(pdev-si_name, de-de_symlink, j);
+   de-de_symlink[0] = 0;
+   while (depth--  0)
+   strcat(de-de_symlink, ../);
+   strcat(de-de_symlink, pdev-si_name);
} else {
de-de_uid = cdp-cdp_c.si_uid;
de-de_gid = cdp-cdp_c.si_gid;
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259261 - head/sys/dev/drm2

2013-12-12 Thread Aleksandr Rybalko
Author: ray
Date: Thu Dec 12 14:49:26 2013
New Revision: 259261
URL: http://svnweb.freebsd.org/changeset/base/259261

Log:
  Do not try to probe/attach if attempt to add fbd child are failed.
  
  Sponsored by: The FreeBSD Foundation

Modified:
  head/sys/dev/drm2/drm_fb_helper.c

Modified: head/sys/dev/drm2/drm_fb_helper.c
==
--- head/sys/dev/drm2/drm_fb_helper.c   Thu Dec 12 14:37:25 2013
(r259260)
+++ head/sys/dev/drm2/drm_fb_helper.c   Thu Dec 12 14:49:26 2013
(r259261)
@@ -1043,7 +1043,10 @@ int drm_fb_helper_single_fb_probe(struct
 
kdev = fb_helper-dev-device;
fbd = device_add_child(kdev, fbd, device_get_unit(kdev));
-   ret = device_probe_and_attach(fbd);
+   if (fbd != NULL) 
+   ret = device_probe_and_attach(fbd);
+   else
+   ret = ENODEV;
 #ifdef DEV_VT
if (ret != 0)
DRM_ERROR(Failed to attach fbd device: %d\n, ret);
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259265 - head/sys/mips/beri

2013-12-12 Thread Bjoern A. Zeeb
Author: bz
Date: Thu Dec 12 17:48:33 2013
New Revision: 259265
URL: http://svnweb.freebsd.org/changeset/base/259265

Log:
  Use correct value pointing to previously selected FDT DTB.
  
  Reviewed by:  brooks
  Sponsored by: DARPA, AFRL
  MFC after:1 week

Modified:
  head/sys/mips/beri/beri_machdep.c

Modified: head/sys/mips/beri/beri_machdep.c
==
--- head/sys/mips/beri/beri_machdep.c   Thu Dec 12 16:58:45 2013
(r259264)
+++ head/sys/mips/beri/beri_machdep.c   Thu Dec 12 17:48:33 2013
(r259265)
@@ -178,7 +178,7 @@ platform_start(__register_t a0, __regist
 
if (OF_install(OFW_FDT, 0) == FALSE)
while (1);
-   if (OF_init(fdt_static_dtb) != 0)
+   if (OF_init((void *)dtbp) != 0)
while (1);
 #endif
 
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259266 - head/usr.sbin/pkg

2013-12-12 Thread Bryan Drewery
Author: bdrewery (ports committer)
Date: Thu Dec 12 17:59:09 2013
New Revision: 259266
URL: http://svnweb.freebsd.org/changeset/base/259266

Log:
  Fix multi-repository support by properly respecting 'enabled' flag.
  
  This will read the REPOS_DIR env/config setting (default is /etc/pkg
  and /usr/local/etc/pkg/repos) and use the last enabled repository.
  
  This can be changed in the environment using a comma-separated list,
  or in /usr/local/etc/pkg.conf with JSON array syntax of:
  REPOS_DIR: [/etc/pkg, /usr/local/etc/pkg/repos]
  
  Approved by:  bapt
  MFC after:1 week

Modified:
  head/usr.sbin/pkg/config.c
  head/usr.sbin/pkg/config.h
  head/usr.sbin/pkg/pkg.7

Modified: head/usr.sbin/pkg/config.c
==
--- /dev/null   00:00:00 1970   (empty, because file is newly added)
+++ head/sys/boot/fdt/dts/beri-netfpga.dts  Thu Dec 12 18:08:31 2013
(r259267)
@@ -0,0 +1,135 @@
+/*-
+ * Copyright (c) 2012-2013 Robert N. M. Watson
+ * Copyright (c) 2013 SRI International
+ * Copyright (c) 2013 Bjoern A. Zeeb
+ * All rights reserved.
+ *
+ * This software was developed by SRI International and the University of
+ * Cambridge Computer Laboratory under DARPA/AFRL contract (FA8750-10-C-0237)
+ * (CTSRD), as part of the DARPA CRASH research programme.
+ *
+ * This software was developed by SRI International and the University of
+ * Cambridge Computer Laboratory under DARPA/AFRL contract (FA8750-11-C-0249)
+ * (MRC2), as part of the DARPA MRC research programme.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *notice, this list of conditions and the following disclaimer in the
+ *documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ *
+ * $FreeBSD$
+ */
+
+/dts-v1/;
+
+/*
+ * Device names here have been largely made up on the spot, especially for the
+ * compatible strings, and might want to be revised.
+ */
+
+/ {
+   model = SRI/Cambridge Beri (NetFPGA);
+   compatible = sri-cambridge,beri-netfpga;
+   #address-cells = 1;
+   #size-cells = 1;
+
+   cpus {
+   #address-cells = 1;
+   #size-cells = 1;
+
+   /*
+* Secondary CPUs all start disabled and use the
+* spin-table enable method.  cpu-release-addr must be
+* specified for each cpu other than cpu@0.  Values of
+* cpu-release-addr grow down from 0x10 (kernel).
+*/
+   status = disabled;
+   enable-method = spin-table;
+
+   cpu@0 {
+   device-type = cpu;
+   compatible = sri-cambridge,beri;
+
+   reg = 0;
+   status = okay;
+   };
+
+/*
+   cpu@1 {
+   device-type = cpu;
+   compatible = sri-cambridge,beri;
+
+   reg = 1;
+   // XXX: should we need cached prefix?
+   cpu-release-addr = 0x 0x800fffe0;
+   };
+*/
+   };
+
+   soc {
+   #address-cells = 1;
+   #size-cells = 1;
+   #interrupt-cells = 1;
+
+   /*
+* Declare mips,mips4k since BERI doesn't (yet) have a PIC, so
+* we use mips4k coprocessor 0 interrupt management directly.
+*/
+   compatible = simple-bus, mips,mips4k;
+   ranges = ;
+
+   memory {
+   device_type = memory;
+   reg = 0x0 0x0FFF; // ~256M at 0x0
+   };
+
+   beripic: beripic@7f804000 {
+   compatible = sri-cambridge,beri-pic;
+   interrupt-controller;
+   #address-cells = 0;
+   #interrupt-cells = 1;
+   reg = 0x7f804000 0x400
+  0x7f806000 0x10
+  0x7f806080 

svn commit: r259270 - in head/sys/arm: freescale/imx ti

2013-12-12 Thread Luiz Otavio O Souza
Author: loos
Date: Thu Dec 12 18:29:36 2013
New Revision: 259270
URL: http://svnweb.freebsd.org/changeset/base/259270

Log:
  After r256961 ofw_iicbuc.c will be built for any kernel which includes
  options 'iicbus' and 'fdt'.  Remove the (now) unnecessary entries.
  
  Verified on BBB (am335x), EFIKA_MX (imx51 - by ray@), DIGI-CCWMX53
  (imx53 - kernel build).
  
  Approved by:  adrian (mentor)

Modified:
  head/sys/arm/freescale/imx/files.imx51
  head/sys/arm/freescale/imx/files.imx53
  head/sys/arm/freescale/imx/files.imx6
  head/sys/arm/ti/files.ti

Modified: head/sys/arm/freescale/imx/files.imx51
==
--- head/sys/arm/freescale/imx/files.imx51  Thu Dec 12 18:16:46 2013
(r259269)
+++ head/sys/arm/freescale/imx/files.imx51  Thu Dec 12 18:29:36 2013
(r259270)
@@ -46,7 +46,6 @@ arm/freescale/imx/imx_wdog.c  optional i
 
 # i2c
 arm/freescale/imx/i2c.coptional fsliic
-dev/ofw/ofw_iicbus.c   optional fsliic
 
 # IPU - Image Processing Unit (frame buffer also)
 arm/freescale/imx/imx51_ipuv3.coptional sc

Modified: head/sys/arm/freescale/imx/files.imx53
==
--- head/sys/arm/freescale/imx/files.imx53  Thu Dec 12 18:16:46 2013
(r259269)
+++ head/sys/arm/freescale/imx/files.imx53  Thu Dec 12 18:29:36 2013
(r259270)
@@ -46,7 +46,6 @@ arm/freescale/imx/imx_wdog.c  optional i
 
 # i2c
 arm/freescale/imx/i2c.coptional fsliic
-dev/ofw/ofw_iicbus.c   optional fsliic
 
 # IPU - Image Processing Unit (frame buffer also)
 arm/freescale/imx/imx51_ipuv3.coptional sc

Modified: head/sys/arm/freescale/imx/files.imx6
==
--- head/sys/arm/freescale/imx/files.imx6   Thu Dec 12 18:16:46 2013
(r259269)
+++ head/sys/arm/freescale/imx/files.imx6   Thu Dec 12 18:29:36 2013
(r259270)
@@ -51,6 +51,5 @@ arm/freescale/imx/imx6_usbphy.c   optiona
 #arm/freescale/imx/imx51_gpio.coptional gpio
 #dev/ata/chipsets/ata-fsl.coptional imxata
 #arm/freescale/imx/i2c.c   optional fsliic
-#dev/ofw/ofw_iicbus.c  optional fsliic
 #arm/freescale/imx/imx51_ipuv3.c   optional sc
 

Modified: head/sys/arm/ti/files.ti
==
--- head/sys/arm/ti/files.tiThu Dec 12 18:16:46 2013(r259269)
+++ head/sys/arm/ti/files.tiThu Dec 12 18:29:36 2013(r259270)
@@ -22,7 +22,6 @@ arm/ti/ti_pruss.c standard
 
 arm/ti/ti_gpio.c   optionalgpio
 arm/ti/ti_i2c.coptionalti_i2c
-dev/ofw/ofw_iicbus.c   optionaliicbus
 
 dev/uart/uart_dev_ti8250.c optionaluart
 dev/uart/uart_dev_ns8250.c optionaluart
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


Re: svn commit: r259261 - head/sys/dev/drm2

2013-12-12 Thread Konstantin Belousov
On Thu, Dec 12, 2013 at 02:49:27PM +, Aleksandr Rybalko wrote:
 Author: ray
 Date: Thu Dec 12 14:49:26 2013
 New Revision: 259261
 URL: http://svnweb.freebsd.org/changeset/base/259261
 
 Log:
   Do not try to probe/attach if attempt to add fbd child are failed.
   
   Sponsored by:   The FreeBSD Foundation
 
 Modified:
   head/sys/dev/drm2/drm_fb_helper.c
 
 Modified: head/sys/dev/drm2/drm_fb_helper.c
 ==
 --- head/sys/dev/drm2/drm_fb_helper.c Thu Dec 12 14:37:25 2013
 (r259260)
 +++ head/sys/dev/drm2/drm_fb_helper.c Thu Dec 12 14:49:26 2013
 (r259261)
 @@ -1043,7 +1043,10 @@ int drm_fb_helper_single_fb_probe(struct
  
   kdev = fb_helper-dev-device;
   fbd = device_add_child(kdev, fbd, device_get_unit(kdev));
 - ret = device_probe_and_attach(fbd);
 + if (fbd != NULL) 
 + ret = device_probe_and_attach(fbd);
 + else
 + ret = ENODEV;
This must be -ENODEV, since linux layer operates on negative values for
error.  The error is negated in the drm layer, which would result in
non-existent errno returned to FreeBSD code.

Also, the #ifdef __FreeBSD braces in the file are not useful, please
remove them.
  #ifdef DEV_VT
   if (ret != 0)
   DRM_ERROR(Failed to attach fbd device: %d\n, ret);


pgpL8OsKS89FH.pgp
Description: PGP signature


svn commit: r259274 - head/release/doc/en_US.ISO8859-1/relnotes

2013-12-12 Thread Craig Rodrigues
Author: rodrigc
Date: Thu Dec 12 20:20:46 2013
New Revision: 259274
URL: http://svnweb.freebsd.org/changeset/base/259274

Log:
  Mention BIND removal in release notes.
  
  Submitted by: skreuzer

Modified:
  head/release/doc/en_US.ISO8859-1/relnotes/article.xml

Modified: head/release/doc/en_US.ISO8859-1/relnotes/article.xml
==
--- head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Thu Dec 12 
19:02:42 2013(r259273)
+++ head/release/doc/en_US.ISO8859-1/relnotes/article.xml   Thu Dec 12 
20:20:46 2013(r259274)
@@ -328,6 +328,13 @@
   sect2 xml:id=userland
 titleUserland Changes/title
 
+para role=mergedBIND has been replaced by man.unbound.8; for
+  local dns resolution in the base system.  With this change, nslookup
+  and dig are no longer a part of the base system.  Users should
+  instead use man.host.1; and man.drill.1; Alternatively,
+  nslookup and dig can be obtained by installing the
+  dns/bind-tools port./para
+
 para role=mergedThe man.adduser.8; utility now supports
   a option-M/option option to set the mode of a new user's
   home directory./para
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259275 - head/usr.sbin/bhyvectl

2013-12-12 Thread John Baldwin
Author: jhb
Date: Thu Dec 12 20:34:04 2013
New Revision: 259275
URL: http://svnweb.freebsd.org/changeset/base/259275

Log:
  Add a command to inject an NMI on a specific vcpu.  It is a simple
  wrapper around the existing vm_inject_nmi().
  
  Reviewed by:  grehan, neel

Modified:
  head/usr.sbin/bhyvectl/bhyvectl.c

Modified: head/usr.sbin/bhyvectl/bhyvectl.c
==
--- head/usr.sbin/bhyvectl/bhyvectl.c   Thu Dec 12 20:20:46 2013
(r259274)
+++ head/usr.sbin/bhyvectl/bhyvectl.c   Thu Dec 12 20:34:04 2013
(r259275)
@@ -189,12 +189,14 @@ usage(void)
   [--set-mem=memory in units of MB]\n
   [--get-lowmem]\n
   [--get-highmem]\n
-  [--get-gpa-pmap]\n,
+  [--get-gpa-pmap]\n
+  [--inject-nmi]\n,
progname);
exit(1);
 }
 
 static int get_stats, getcap, setcap, capval, get_gpa_pmap;
+static int inject_nmi;
 static const char *capname;
 static int create, destroy, get_lowmem, get_highmem;
 static uint64_t memsize;
@@ -557,6 +559,7 @@ main(int argc, char *argv[])
{ run,NO_ARG, run,   1 },
{ create, NO_ARG, create,1 },
{ destroy,NO_ARG, destroy,   1 },
+   { inject-nmi, NO_ARG, inject_nmi,1 },
{ NULL, 0,  NULL,   0 }
};
 
@@ -825,6 +828,10 @@ main(int argc, char *argv[])
  vmcs_entry_interruption_info);
}
 
+   if (!error  inject_nmi) {
+   error = vm_inject_nmi(ctx, vcpu);
+   }
+
if (!error  (get_lowmem || get_all)) {
gpa = 0;
error = vm_get_memory_seg(ctx, gpa, len, wired);
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259276 - head/usr.sbin/bsdinstall/scripts

2013-12-12 Thread Devin Teske
Author: dteske
Date: Thu Dec 12 20:47:18 2013
New Revision: 259276
URL: http://svnweb.freebsd.org/changeset/base/259276

Log:
  I caught the following snippet at the end of my /var/log/bsdinstall_log:
  ===
  DEBUG: Running installation step: services
  local: Not in a function
  /usr/libexec/bsdinstall/services: cannot create  : Read-only file system
  /usr/libexec/bsdinstall/services: /tmp/bsdinstall/etc/rc.conf.services: \
   Permission denied
  ===
  The `local: Not in a function' is obvious, and was introduced by myself in
  SVN revision 256348.
  
  The latter two are caused by the attempt to use \ to continue the line
  after using the  redirect. This appears to attempt to write a file with
  the name   in the current directory and subsequently attempts to execute
  the file that was originally intended for writing (which is not executable;
  hence the `Permission denied'). That was introduced in SVN r228192 about
  2 years ago, apparently unnoticed until I started going over the debug
  outputs very carefully.
  
  MFC after:3 days

Modified:
  head/usr.sbin/bsdinstall/scripts/services

Modified: head/usr.sbin/bsdinstall/scripts/services
==
--- head/usr.sbin/bsdinstall/scripts/services   Thu Dec 12 20:34:04 2013
(r259275)
+++ head/usr.sbin/bsdinstall/scripts/services   Thu Dec 12 20:47:18 2013
(r259276)
@@ -50,13 +50,12 @@ DAEMONS=$(dialog --backtitle FreeBSD In
 21 13)
 exec 3-
 
-local havedump=
+havedump=
 for daemon in $DAEMONS; do
if [ $daemon == dumpdev ]; then
havedump=1
-   echo \# Set dumpdev to \AUTO\ to enable crash dumps, \
-   \NO\ to disable  \ 
-   $BSDINSTALL_TMPETC/rc.conf.services
+   echo '# Set dumpdev to AUTO to enable crash dumps, NO' \
+'to disable'  $BSDINSTALL_TMPETC/rc.conf.services
echo dumpdev=\AUTO\  $BSDINSTALL_TMPETC/rc.conf.services
continue
fi
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259280 - head/sbin/growfs

2013-12-12 Thread Gleb Smirnoff
Author: glebius
Date: Thu Dec 12 22:33:32 2013
New Revision: 259280
URL: http://svnweb.freebsd.org/changeset/base/259280

Log:
  Somehow stable/10 branch contains correct version, but head doesn't.

Modified:
  head/sbin/growfs/growfs.8

Modified: head/sbin/growfs/growfs.8
==
--- head/sbin/growfs/growfs.8   Thu Dec 12 22:04:47 2013(r259279)
+++ head/sbin/growfs/growfs.8   Thu Dec 12 22:33:32 2013(r259280)
@@ -116,7 +116,7 @@ The
 utility first appeared in
 .Fx 4.4 .
 The ability to resize mounted filesystems was added in
-.Fx 9.2 .
+.Fx 10.0 .
 .Sh AUTHORS
 .An Christoph Herrmann Aq c...@freebsd.org
 .An Thomas-Henning von Kamptz Aq toms...@freebsd.org
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259284 - in head/sys: conf powerpc/aim powerpc/cpufreq powerpc/include powerpc/powermac powerpc/powerpc

2013-12-12 Thread Justin Hibbits
Author: jhibbits
Date: Fri Dec 13 02:37:35 2013
New Revision: 259284
URL: http://svnweb.freebsd.org/changeset/base/259284

Log:
  Add PMU-based CPU frequency scaling.  This method is used on most Titanium
  PowerBooks.
  
  MFC after:1 month

Added:
  head/sys/powerpc/cpufreq/pmufreq.c   (contents, props changed)
Modified:
  head/sys/conf/files.powerpc
  head/sys/powerpc/aim/mp_cpudep.c
  head/sys/powerpc/include/cpu.h
  head/sys/powerpc/include/dbdma.h
  head/sys/powerpc/include/pcpu.h
  head/sys/powerpc/include/spr.h
  head/sys/powerpc/powermac/platform_powermac.c
  head/sys/powerpc/powermac/pmu.c
  head/sys/powerpc/powermac/pmuvar.h
  head/sys/powerpc/powermac/uninorth.c
  head/sys/powerpc/powermac/uninorthvar.h
  head/sys/powerpc/powermac/viareg.h
  head/sys/powerpc/powerpc/mp_machdep.c

Modified: head/sys/conf/files.powerpc
==
--- head/sys/conf/files.powerpc Fri Dec 13 02:21:32 2013(r259283)
+++ head/sys/conf/files.powerpc Fri Dec 13 02:37:35 2013(r259284)
@@ -107,6 +107,7 @@ powerpc/booke/pmap.coptionalbooke
 powerpc/booke/trap.c   optionalbooke
 powerpc/cpufreq/dfs.c  optionalcpufreq
 powerpc/cpufreq/pcr.c  optionalcpufreq aim
+powerpc/cpufreq/pmufreq.c  optionalcpufreq aim pmu
 powerpc/fpu/fpu_add.c  optionalfpu_emu
 powerpc/fpu/fpu_compare.c  optionalfpu_emu
 powerpc/fpu/fpu_div.c  optionalfpu_emu

Modified: head/sys/powerpc/aim/mp_cpudep.c
==
--- head/sys/powerpc/aim/mp_cpudep.cFri Dec 13 02:21:32 2013
(r259283)
+++ head/sys/powerpc/aim/mp_cpudep.cFri Dec 13 02:37:35 2013
(r259284)
@@ -322,17 +322,13 @@ cpudep_ap_setup()
mtspr(SPR_CELL_TSRL, bsp_state[5]);
 
break;
-   case MPC7450:
-   case MPC7455:
-   case MPC7457:
-   /* Only MPC745x CPUs have an L3 cache. */
-   reg = mpc745x_l3_enable(bsp_state[3]);
-   
-   /* Fallthrough */
case MPC7400:
case MPC7410:
case MPC7447A:
case MPC7448:
+   case MPC7450:
+   case MPC7455:
+   case MPC7457:
/* XXX: Program the CPU ID into PIR */
__asm __volatile(mtspr 1023,%0 :: r(PCPU_GET(cpuid)));
 
@@ -342,6 +338,17 @@ cpudep_ap_setup()
mtspr(SPR_HID0, bsp_state[0]); isync();
mtspr(SPR_HID1, bsp_state[1]); isync();
 
+   /* Now enable the L3 cache. */
+   switch (vers) {
+   case MPC7450:
+   case MPC7455:
+   case MPC7457:
+   /* Only MPC745x CPUs have an L3 cache. */
+   reg = mpc745x_l3_enable(bsp_state[3]);
+   default:
+   break;
+   }
+   
reg = mpc74xx_l2_enable(bsp_state[2]);
reg = mpc74xx_l1d_enable();
reg = mpc74xx_l1i_enable();

Added: head/sys/powerpc/cpufreq/pmufreq.c
==
--- /dev/null   00:00:00 1970   (empty, because file is newly added)
+++ head/sys/powerpc/cpufreq/pmufreq.c  Fri Dec 13 02:37:35 2013
(r259284)
@@ -0,0 +1,222 @@
+/*-
+ * Copyright (c) 2011 Justin Hibbits
+ * Copyright (c) 2009 Nathan Whitehorn
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *notice, this list of conditions and the following disclaimer in the
+ *documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
+ * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
+#include sys/cdefs.h
+__FBSDID($FreeBSD$);
+
+#include sys/param.h
+#include sys/systm.h
+#include sys/bus.h
+#include sys/cpu.h
+#include sys/kernel.h

svn commit: r259286 - head/crypto/heimdal/lib/gssapi/krb5

2013-12-12 Thread Benjamin Kaduk
Author: bjk (doc committer)
Date: Fri Dec 13 03:09:29 2013
New Revision: 259286
URL: http://svnweb.freebsd.org/changeset/base/259286

Log:
  Apply patch from upstream Heimdal for encoding fix
  
  RFC 4402 specifies the implementation of the gss_pseudo_random()
  function for the krb5 mechanism (and the C bindings therein).
  The implementation uses a PRF+ function that concatenates the output
  of individual krb5 pseudo-random operations produced with a counter
  and seed.  The original implementation of this function in Heimdal
  incorrectly encoded the counter as a little-endian integer, but the
  RFC specifies the counter encoding as big-endian.  The implementation
  initializes the counter to zero, so the first block of output (16 octets,
  for the modern AES enctypes 17 and 18) is unchanged.  (RFC 4402 specifies
  that the counter should begin at 1, but both existing implementations
  begin with zero and it looks like the standard will be re-issued, with
  test vectors, to begin at zero.)
  
  This is upstream's commit f85652af868e64811f2b32b815d4198e7f9017f6,
  from 13 October, 2013:
  % Fix krb5's gss_pseudo_random() (n is big-endian)
  %
  % The first enctype RFC3961 prf output length's bytes are correct because
  % the little- and big-endian representations of unsigned zero are the
  % same.  The second block of output was wrong because the counter was not
  % being encoded as big-endian.
  %
  % This change could break applications.  But those applications would not
  % have been interoperating with other implementations anyways (in
  % particular: MIT's).
  
  Approved by:  hrs (mentor, src committer)
  MFC after:3 days

Modified:
  head/crypto/heimdal/lib/gssapi/krb5/prf.c

Modified: head/crypto/heimdal/lib/gssapi/krb5/prf.c
==
--- head/crypto/heimdal/lib/gssapi/krb5/prf.c   Fri Dec 13 02:47:41 2013
(r259285)
+++ head/crypto/heimdal/lib/gssapi/krb5/prf.c   Fri Dec 13 03:09:29 2013
(r259286)
@@ -119,7 +119,7 @@ _gsskrb5_pseudo_random(OM_uint32 *minor_
 while(dol  0) {
size_t tsize;
 
-   _gsskrb5_encode_om_uint32(num, input.data);
+   _gsskrb5_encode_be_om_uint32(num, input.data);
 
ret = krb5_crypto_prf(context, crypto, input, output);
if (ret) {
@@ -133,7 +133,7 @@ _gsskrb5_pseudo_random(OM_uint32 *minor_
 
tsize = min(dol, output.length);
memcpy(p, output.data, tsize);
-   p += output.length;
+   p += tsize;
dol -= tsize;
krb5_data_free(output);
num++;
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


svn commit: r259287 - head/sys/powerpc/cpufreq

2013-12-12 Thread Justin Hibbits
Author: jhibbits
Date: Fri Dec 13 05:54:25 2013
New Revision: 259287
URL: http://svnweb.freebsd.org/changeset/base/259287

Log:
  Some style(9) fixes
  
  MFC after:1 month
  X-MFC with: r259284

Modified:
  head/sys/powerpc/cpufreq/pmufreq.c

Modified: head/sys/powerpc/cpufreq/pmufreq.c
==
--- head/sys/powerpc/cpufreq/pmufreq.c  Fri Dec 13 03:09:29 2013
(r259286)
+++ head/sys/powerpc/cpufreq/pmufreq.c  Fri Dec 13 05:54:25 2013
(r259287)
@@ -106,9 +106,9 @@ pmufreq_identify(driver_t *driver, devic
 static int
 pmufreq_probe(device_t dev)
 {
-   uint32_t min_freq;
struct pmufreq_softc *sc;
phandle_t node;
+   uint32_t min_freq;
 
if (resource_disabled(pmufreq, 0))
return (ENXIO);
@@ -174,8 +174,7 @@ static int
 pmufreq_set(device_t dev, const struct cf_setting *set)
 {
struct pmufreq_softc *sc;
-   int speed_sel;
-   int error;
+   int error, speed_sel;
 
if (set == NULL)
return (EINVAL);
@@ -191,7 +190,7 @@ pmufreq_set(device_t dev, const struct c
if (error == 0)
sc-curfreq = set-freq;
 
-   return error;
+   return (error);
 }
 
 static int
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org


Re: svn commit: r259280 - head/sbin/growfs

2013-12-12 Thread Sergey Kandaurov
On 13 December 2013 02:33, Gleb Smirnoff gleb...@freebsd.org wrote:
 Author: glebius
 Date: Thu Dec 12 22:33:32 2013
 New Revision: 259280
 URL: http://svnweb.freebsd.org/changeset/base/259280

 Log:
   Somehow stable/10 branch contains correct version, but head doesn't.

 Modified:
   head/sbin/growfs/growfs.8

 Modified: head/sbin/growfs/growfs.8
 ==
 --- head/sbin/growfs/growfs.8   Thu Dec 12 22:04:47 2013(r259279)
 +++ head/sbin/growfs/growfs.8   Thu Dec 12 22:33:32 2013(r259280)
 @@ -116,7 +116,7 @@ The
  utility first appeared in
  .Fx 4.4 .
  The ability to resize mounted filesystems was added in
 -.Fx 9.2 .
 +.Fx 10.0 .
  .Sh AUTHORS
  .An Christoph Herrmann Aq c...@freebsd.org
  .An Thomas-Henning von Kamptz Aq toms...@freebsd.org

It was merged in stable/9 before 9.2 in r246235.

--- head/usr.sbin/pkg/config.c  Thu Dec 12 17:48:33 2013(r259265)
+++ head/usr.sbin/pkg/config.c  Thu Dec 12 17:59:09 2013(r259266)
@@ -32,8 +32,10 @@ __FBSDID($FreeBSD$);
 #include sys/sbuf.h
 #include sys/elf_common.h
 #include sys/endian.h
+#include sys/types.h
 
 #include assert.h
+#include dirent.h
 #include yaml.h
 #include ctype.h
 #include err.h
@@ -51,11 +53,17 @@ __FBSDID($FreeBSD$);
 
 #define roundup2(x, y) (((x)+((y)-1))(~((y)-1))) /* if y is powers of two */
 
+struct config_value {
+   char *value;
+   STAILQ_ENTRY(config_value) next;
+};
+
 struct config_entry {
uint8_t type;
const char *key;
const char *val;
char *value;
+   STAILQ_HEAD(, config_value) *list;
bool envset;
 };
 
@@ -65,6 +73,7 @@ static struct config_entry c[] = {
PACKAGESITE,
URL_SCHEME_PREFIX http://pkg.FreeBSD.org/${ABI}/latest;,
NULL,
+   NULL,
false,
},
[ABI] = {
@@ -72,6 +81,7 @@ static struct config_entry c[] = {
ABI,
NULL,
NULL,
+   NULL,
false,
},
[MIRROR_TYPE] = {
@@ -79,6 +89,7 @@ static struct config_entry c[] = {
MIRROR_TYPE,
SRV,
NULL,
+   NULL,
false,
},
[ASSUME_ALWAYS_YES] = {
@@ -86,6 +97,7 @@ static struct config_entry c[] = {
ASSUME_ALWAYS_YES,
NO,
NULL,
+   NULL,
false,
},
[SIGNATURE_TYPE] = {
@@ -93,6 +105,7 @@ static struct config_entry c[] = {
SIGNATURE_TYPE,
NULL,
NULL,
+   NULL,
false,
},
[FINGERPRINTS] = {
@@ -100,6 +113,15 @@ static struct config_entry c[] = {
FINGERPRINTS,
NULL,
NULL,
+   NULL,
+   false,
+   },
+   [REPOS_DIR] = {
+   PKG_CONFIG_LIST,
+   REPOS_DIR,
+   NULL,
+   NULL,
+   NULL,
false,
},
 };
@@ -474,17 +496,34 @@ subst_packagesite(const char *abi)
c[PACKAGESITE].value = strdup(sbuf_data(newval));
 }
 
+static int
+boolstr_to_bool(const char *str)
+{
+   if (str != NULL  (strcasecmp(str, true) == 0 ||
+   strcasecmp(str, yes) == 0 || strcasecmp(str, on) == 0 ||
+   str[0] == '1'))
+   return (true);
+
+   return (false);
+}
+
 static void
 config_parse(yaml_document_t *doc, yaml_node_t *node, pkg_conf_file_t conftype)
 {
+   yaml_node_item_t *item;
yaml_node_pair_t *pair;
-   yaml_node_t *key, *val;
+   yaml_node_t *key, *val, *item_val;
struct sbuf *buf = sbuf_new_auto();
+   struct config_entry *temp_config;
+   struct config_value *cv;
int i;
size_t j;
 
pair = node-data.mapping.pairs.start;
 
+   /* Temporary config for configs that may be disabled. */
+   temp_config = calloc(CONFIG_SIZE, sizeof(struct config_entry));
+
while (pair  node-data.mapping.pairs.top) {
key = yaml_document_get_node(doc, pair-key);
val = yaml_document_get_node(doc, pair-value);
@@ -530,7 +569,12 @@ config_parse(yaml_document_t *doc, yaml_
else if (strcasecmp(key-data.scalar.value,
fingerprints) == 0)
sbuf_cpy(buf, FINGERPRINTS);
-   else { /* Skip unknown entries for future use. */
+   else if (strcasecmp(key-data.scalar.value,
+   enabled) == 0) {
+   /* Skip disabled repos. */
+   if (!boolstr_to_bool(val-data.scalar.value))
+   goto cleanup;
+   } else { /* Skip unknown entries for future use. */
++pair;
continue;
}
@@ -554,10 +598,58 

svn commit: r259267 - in head/sys: boot/fdt/dts mips/conf

2013-12-12 Thread Bjoern A. Zeeb
Author: bz
Date: Thu Dec 12 18:08:31 2013
New Revision: 259267
URL: http://svnweb.freebsd.org/changeset/base/259267

Log:
  Add an FDT DTS and MDROOT kernel configuration for BERI on NetFPGA.
  
  At this point we only support one CPU, the PIC, and a UART console.
  
  Reviewed by:  brooks
  Sponsored by: DARPA, AFRL
  MFC after:5 days

Added:
  head/sys/boot/fdt/dts/beri-netfpga.dts   (contents, props changed)
  head/sys/mips/conf/BERI_NETFPGA_MDROOT   (contents, props changed)

Added: head/sys/boot/fdt/dts/beri-netfpga.dts
==
-- 
wbr,
pluknet
___
svn-src-head@freebsd.org mailing list
http://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to svn-src-head-unsubscr...@freebsd.org